@@ -84,36 +84,34 @@ class DictRouter(ExtRouter):
 
         for app_route in self._router_conf.get("apps"):
             version_prefix = app_route.get("version_prefix")
-            version_prefix=version_prefix if version_prefix else "/api/v"
-            for endpoint, params in app_route.get("endpoints").items():
-                methods_confs = []
-                endpoint_version = params.pop("version", None)
-                if not endpoint_version:
-                    raise AttributeError("Need to specify endpoint version")
-                endpoint_handler = params.pop("handler", None)
-                endpoint_protector = params.pop("protector", None)
-                for method_name, method_params in params.items():
-                    target_func = method_params.get('handler')
-                    target_func = target_func if target_func else endpoint_handler
-                    protector = method_params.get("protector")
-                    protector = protector if protector else endpoint_protector
-                    in_dto = method_params.get("in_dto")
-                    out_dto = method_params.get("out_dto")
-                    chain = self.chaining(
-                        protector=protector,
-                        in_struct=in_dto)(target_func)
-                    methods_confs.append(RouteMethodConf(method_name=method_name,
-                                                         protector=protector,
-                                                         in_dto=in_dto,
-                                                         out_dto=out_dto,
-                                                         handler=target_func
-                                                         ))
-                    chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
-                                             handler=chain, in_dto=in_dto, out_dto=out_dto)
-                    app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain,
-                                  version_prefix=version_prefix, version=endpoint_version)
+            version_prefix = version_prefix if version_prefix else "/api/v"
+            for endpoint, versions in app_route.get("endpoints").items():
+                for version, params in versions.items():
+                    methods_confs = []
+                    endpoint_handler = params.pop("handler", None)
+                    endpoint_protector = params.pop("protector", None)
+                    for method_name, method_params in params.items():
+                        target_func = method_params.get('handler')
+                        target_func = target_func if target_func else endpoint_handler
+                        protector = method_params.get("protector")
+                        protector = protector if protector else endpoint_protector
+                        in_dto = method_params.get("in_dto")
+                        out_dto = method_params.get("out_dto")
+                        chain = self.chaining(
+                            protector=protector,
+                            in_struct=in_dto)(target_func)
+                        methods_confs.append(RouteMethodConf(method_name=method_name,
+                                                             protector=protector,
+                                                             in_dto=in_dto,
+                                                             out_dto=out_dto,
+                                                             handler=target_func
+                                                             ))
+                        chain = add_openapi_spec(uri=endpoint, method_name=method_name, func=target_func,
+                                                 handler=chain, in_dto=in_dto, out_dto=out_dto)
+                        app.add_route(uri=endpoint, methods={method_name.upper()}, handler=chain,
+                                      version_prefix=version_prefix, version=version)
 
-                route = RouteConf(app_name=app_route.get("app_name"), path=endpoint, methods=methods_confs)
-                self.chains.append(route)
+                    route = RouteConf(app_name=app_route.get("app_name"), path=endpoint, methods=methods_confs)
+                    self.chains.append(route)
 
         # warn(f"Can't find dto or handler in imported module, suppressed exception: {e.__str__()}")
